"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.base.query.v1beta1.pagination_pb2
import cosmos.staking.v1beta1.staking_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class QueryValidatorsRequest(google.protobuf.message.Message):
    """QueryValidatorsRequest is request type for Query/Validators RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    status: builtins.str
    """status enables to query for validators matching a given status."""
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """pagination defines an optional pagination for the request."""
    def __init__(
        self,
        *,
        status: builtins.str = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination", b"pagination", "status", b"status"]) -> None: ...

global___QueryValidatorsRequest = QueryValidatorsRequest

@typing_extensions.final
class QueryValidatorsResponse(google.protobuf.message.Message):
    """QueryValidatorsResponse is response type for the Query/Validators RPC method"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALIDATORS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def validators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.staking.v1beta1.staking_pb2.Validator]:
        """validators contains all the queried validators."""
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """pagination defines the pagination in the response."""
    def __init__(
        self,
        *,
        validators: collections.abc.Iterable[cosmos.staking.v1beta1.staking_pb2.Validator] | None = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination", b"pagination", "validators", b"validators"]) -> None: ...

global___QueryValidatorsResponse = QueryValidatorsResponse

@typing_extensions.final
class QueryValidatorRequest(google.protobuf.message.Message):
    """QueryValidatorRequest is response type for the Query/Validator RPC method"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALIDATOR_ADDR_FIELD_NUMBER: builtins.int
    validator_addr: builtins.str
    """validator_addr defines the validator address to query for."""
    def __init__(
        self,
        *,
        validator_addr: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["validator_addr", b"validator_addr"]) -> None: ...

global___QueryValidatorRequest = QueryValidatorRequest

@typing_extensions.final
class QueryValidatorResponse(google.protobuf.message.Message):
    """QueryValidatorResponse is response type for the Query/Validator RPC method"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALIDATOR_FIELD_NUMBER: builtins.int
    @property
    def validator(self) -> cosmos.staking.v1beta1.staking_pb2.Validator:
        """validator defines the the validator info."""
    def __init__(
        self,
        *,
        validator: cosmos.staking.v1beta1.staking_pb2.Validator | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["validator", b"validator"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["validator", b"validator"]) -> None: ...

global___QueryValidatorResponse = QueryValidatorResponse

@typing_extensions.final
class QueryValidatorDelegationsRequest(google.protobuf.message.Message):
    """QueryValidatorDelegationsRequest is request type for the
    Query/ValidatorDelegations RPC method
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALIDATOR_ADDR_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    validator_addr: builtins.str
    """validator_addr defines the validator address to query for."""
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """pagination defines an optional pagination for the request."""
    def __init__(
        self,
        *,
        validator_addr: builtins.str = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination", b"pagination", "validator_addr", b"validator_addr"]) -> None: ...

global___QueryValidatorDelegationsRequest = QueryValidatorDelegationsRequest

@typing_extensions.final
class QueryValidatorDelegationsResponse(google.protobuf.message.Message):
    """QueryValidatorDelegationsResponse is response type for the
    Query/ValidatorDelegations RPC method
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELEGATION_RESPONSES_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def delegation_responses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.staking.v1beta1.staking_pb2.DelegationResponse]: ...
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """pagination defines the pagination in the response."""
    def __init__(
        self,
        *,
        delegation_responses: collections.abc.Iterable[cosmos.staking.v1beta1.staking_pb2.DelegationResponse] | None = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delegation_responses", b"delegation_responses", "pagination", b"pagination"]) -> None: ...

global___QueryValidatorDelegationsResponse = QueryValidatorDelegationsResponse

@typing_extensions.final
class QueryValidatorUnbondingDelegationsRequest(google.protobuf.message.Message):
    """QueryValidatorUnbondingDelegationsRequest is required type for the
    Query/ValidatorUnbondingDelegations RPC method
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALIDATOR_ADDR_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    validator_addr: builtins.str
    """validator_addr defines the validator address to query for."""
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """pagination defines an optional pagination for the request."""
    def __init__(
        self,
        *,
        validator_addr: builtins.str = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination", b"pagination", "validator_addr", b"validator_addr"]) -> None: ...

global___QueryValidatorUnbondingDelegationsRequest = QueryValidatorUnbondingDelegationsRequest

@typing_extensions.final
class QueryValidatorUnbondingDelegationsResponse(google.protobuf.message.Message):
    """QueryValidatorUnbondingDelegationsResponse is response type for the
    Query/ValidatorUnbondingDelegations RPC method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNBONDING_RESPONSES_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def unbonding_responses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.staking.v1beta1.staking_pb2.UnbondingDelegation]: ...
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """pagination defines the pagination in the response."""
    def __init__(
        self,
        *,
        unbonding_responses: collections.abc.Iterable[cosmos.staking.v1beta1.staking_pb2.UnbondingDelegation] | None = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination", b"pagination", "unbonding_responses", b"unbonding_responses"]) -> None: ...

global___QueryValidatorUnbondingDelegationsResponse = QueryValidatorUnbondingDelegationsResponse

@typing_extensions.final
class QueryDelegationRequest(google.protobuf.message.Message):
    """QueryDelegationRequest is request type for the Query/Delegation RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELEGATOR_ADDR_FIELD_NUMBER: builtins.int
    VALIDATOR_ADDR_FIELD_NUMBER: builtins.int
    delegator_addr: builtins.str
    """delegator_addr defines the delegator address to query for."""
    validator_addr: builtins.str
    """validator_addr defines the validator address to query for."""
    def __init__(
        self,
        *,
        delegator_addr: builtins.str = ...,
        validator_addr: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delegator_addr", b"delegator_addr", "validator_addr", b"validator_addr"]) -> None: ...

global___QueryDelegationRequest = QueryDelegationRequest

@typing_extensions.final
class QueryDelegationResponse(google.protobuf.message.Message):
    """QueryDelegationResponse is response type for the Query/Delegation RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELEGATION_RESPONSE_FIELD_NUMBER: builtins.int
    @property
    def delegation_response(self) -> cosmos.staking.v1beta1.staking_pb2.DelegationResponse:
        """delegation_responses defines the delegation info of a delegation."""
    def __init__(
        self,
        *,
        delegation_response: cosmos.staking.v1beta1.staking_pb2.DelegationResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["delegation_response", b"delegation_response"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delegation_response", b"delegation_response"]) -> None: ...

global___QueryDelegationResponse = QueryDelegationResponse

@typing_extensions.final
class QueryUnbondingDelegationRequest(google.protobuf.message.Message):
    """QueryUnbondingDelegationRequest is request type for the
    Query/UnbondingDelegation RPC method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELEGATOR_ADDR_FIELD_NUMBER: builtins.int
    VALIDATOR_ADDR_FIELD_NUMBER: builtins.int
    delegator_addr: builtins.str
    """delegator_addr defines the delegator address to query for."""
    validator_addr: builtins.str
    """validator_addr defines the validator address to query for."""
    def __init__(
        self,
        *,
        delegator_addr: builtins.str = ...,
        validator_addr: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delegator_addr", b"delegator_addr", "validator_addr", b"validator_addr"]) -> None: ...

global___QueryUnbondingDelegationRequest = QueryUnbondingDelegationRequest

@typing_extensions.final
class QueryUnbondingDelegationResponse(google.protobuf.message.Message):
    """QueryDelegationResponse is response type for the Query/UnbondingDelegation
    RPC method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNBOND_FIELD_NUMBER: builtins.int
    @property
    def unbond(self) -> cosmos.staking.v1beta1.staking_pb2.UnbondingDelegation:
        """unbond defines the unbonding information of a delegation."""
    def __init__(
        self,
        *,
        unbond: cosmos.staking.v1beta1.staking_pb2.UnbondingDelegation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["unbond", b"unbond"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["unbond", b"unbond"]) -> None: ...

global___QueryUnbondingDelegationResponse = QueryUnbondingDelegationResponse

@typing_extensions.final
class QueryDelegatorDelegationsRequest(google.protobuf.message.Message):
    """QueryDelegatorDelegationsRequest is request type for the
    Query/DelegatorDelegations RPC method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELEGATOR_ADDR_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    delegator_addr: builtins.str
    """delegator_addr defines the delegator address to query for."""
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """pagination defines an optional pagination for the request."""
    def __init__(
        self,
        *,
        delegator_addr: builtins.str = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delegator_addr", b"delegator_addr", "pagination", b"pagination"]) -> None: ...

global___QueryDelegatorDelegationsRequest = QueryDelegatorDelegationsRequest

@typing_extensions.final
class QueryDelegatorDelegationsResponse(google.protobuf.message.Message):
    """QueryDelegatorDelegationsResponse is response type for the
    Query/DelegatorDelegations RPC method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELEGATION_RESPONSES_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def delegation_responses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.staking.v1beta1.staking_pb2.DelegationResponse]:
        """delegation_responses defines all the delegations' info of a delegator."""
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """pagination defines the pagination in the response."""
    def __init__(
        self,
        *,
        delegation_responses: collections.abc.Iterable[cosmos.staking.v1beta1.staking_pb2.DelegationResponse] | None = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delegation_responses", b"delegation_responses", "pagination", b"pagination"]) -> None: ...

global___QueryDelegatorDelegationsResponse = QueryDelegatorDelegationsResponse

@typing_extensions.final
class QueryDelegatorUnbondingDelegationsRequest(google.protobuf.message.Message):
    """QueryDelegatorUnbondingDelegationsRequest is request type for the
    Query/DelegatorUnbondingDelegations RPC method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELEGATOR_ADDR_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    delegator_addr: builtins.str
    """delegator_addr defines the delegator address to query for."""
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """pagination defines an optional pagination for the request."""
    def __init__(
        self,
        *,
        delegator_addr: builtins.str = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delegator_addr", b"delegator_addr", "pagination", b"pagination"]) -> None: ...

global___QueryDelegatorUnbondingDelegationsRequest = QueryDelegatorUnbondingDelegationsRequest

@typing_extensions.final
class QueryDelegatorUnbondingDelegationsResponse(google.protobuf.message.Message):
    """QueryUnbondingDelegatorDelegationsResponse is response type for the
    Query/UnbondingDelegatorDelegations RPC method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNBONDING_RESPONSES_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def unbonding_responses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.staking.v1beta1.staking_pb2.UnbondingDelegation]: ...
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """pagination defines the pagination in the response."""
    def __init__(
        self,
        *,
        unbonding_responses: collections.abc.Iterable[cosmos.staking.v1beta1.staking_pb2.UnbondingDelegation] | None = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination", b"pagination", "unbonding_responses", b"unbonding_responses"]) -> None: ...

global___QueryDelegatorUnbondingDelegationsResponse = QueryDelegatorUnbondingDelegationsResponse

@typing_extensions.final
class QueryRedelegationsRequest(google.protobuf.message.Message):
    """QueryRedelegationsRequest is request type for the Query/Redelegations RPC
    method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELEGATOR_ADDR_FIELD_NUMBER: builtins.int
    SRC_VALIDATOR_ADDR_FIELD_NUMBER: builtins.int
    DST_VALIDATOR_ADDR_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    delegator_addr: builtins.str
    """delegator_addr defines the delegator address to query for."""
    src_validator_addr: builtins.str
    """src_validator_addr defines the validator address to redelegate from."""
    dst_validator_addr: builtins.str
    """dst_validator_addr defines the validator address to redelegate to."""
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """pagination defines an optional pagination for the request."""
    def __init__(
        self,
        *,
        delegator_addr: builtins.str = ...,
        src_validator_addr: builtins.str = ...,
        dst_validator_addr: builtins.str = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delegator_addr", b"delegator_addr", "dst_validator_addr", b"dst_validator_addr", "pagination", b"pagination", "src_validator_addr", b"src_validator_addr"]) -> None: ...

global___QueryRedelegationsRequest = QueryRedelegationsRequest

@typing_extensions.final
class QueryRedelegationsResponse(google.protobuf.message.Message):
    """QueryRedelegationsResponse is response type for the Query/Redelegations RPC
    method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REDELEGATION_RESPONSES_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def redelegation_responses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.staking.v1beta1.staking_pb2.RedelegationResponse]: ...
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """pagination defines the pagination in the response."""
    def __init__(
        self,
        *,
        redelegation_responses: collections.abc.Iterable[cosmos.staking.v1beta1.staking_pb2.RedelegationResponse] | None = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination", b"pagination", "redelegation_responses", b"redelegation_responses"]) -> None: ...

global___QueryRedelegationsResponse = QueryRedelegationsResponse

@typing_extensions.final
class QueryDelegatorValidatorsRequest(google.protobuf.message.Message):
    """QueryDelegatorValidatorsRequest is request type for the
    Query/DelegatorValidators RPC method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELEGATOR_ADDR_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    delegator_addr: builtins.str
    """delegator_addr defines the delegator address to query for."""
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """pagination defines an optional pagination for the request."""
    def __init__(
        self,
        *,
        delegator_addr: builtins.str = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delegator_addr", b"delegator_addr", "pagination", b"pagination"]) -> None: ...

global___QueryDelegatorValidatorsRequest = QueryDelegatorValidatorsRequest

@typing_extensions.final
class QueryDelegatorValidatorsResponse(google.protobuf.message.Message):
    """QueryDelegatorValidatorsResponse is response type for the
    Query/DelegatorValidators RPC method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALIDATORS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def validators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.staking.v1beta1.staking_pb2.Validator]:
        """validators defines the the validators' info of a delegator."""
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """pagination defines the pagination in the response."""
    def __init__(
        self,
        *,
        validators: collections.abc.Iterable[cosmos.staking.v1beta1.staking_pb2.Validator] | None = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination", b"pagination", "validators", b"validators"]) -> None: ...

global___QueryDelegatorValidatorsResponse = QueryDelegatorValidatorsResponse

@typing_extensions.final
class QueryDelegatorValidatorRequest(google.protobuf.message.Message):
    """QueryDelegatorValidatorRequest is request type for the
    Query/DelegatorValidator RPC method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELEGATOR_ADDR_FIELD_NUMBER: builtins.int
    VALIDATOR_ADDR_FIELD_NUMBER: builtins.int
    delegator_addr: builtins.str
    """delegator_addr defines the delegator address to query for."""
    validator_addr: builtins.str
    """validator_addr defines the validator address to query for."""
    def __init__(
        self,
        *,
        delegator_addr: builtins.str = ...,
        validator_addr: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delegator_addr", b"delegator_addr", "validator_addr", b"validator_addr"]) -> None: ...

global___QueryDelegatorValidatorRequest = QueryDelegatorValidatorRequest

@typing_extensions.final
class QueryDelegatorValidatorResponse(google.protobuf.message.Message):
    """QueryDelegatorValidatorResponse response type for the
    Query/DelegatorValidator RPC method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALIDATOR_FIELD_NUMBER: builtins.int
    @property
    def validator(self) -> cosmos.staking.v1beta1.staking_pb2.Validator:
        """validator defines the the validator info."""
    def __init__(
        self,
        *,
        validator: cosmos.staking.v1beta1.staking_pb2.Validator | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["validator", b"validator"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["validator", b"validator"]) -> None: ...

global___QueryDelegatorValidatorResponse = QueryDelegatorValidatorResponse

@typing_extensions.final
class QueryHistoricalInfoRequest(google.protobuf.message.Message):
    """QueryHistoricalInfoRequest is request type for the Query/HistoricalInfo RPC
    method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEIGHT_FIELD_NUMBER: builtins.int
    height: builtins.int
    """height defines at which height to query the historical info."""
    def __init__(
        self,
        *,
        height: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["height", b"height"]) -> None: ...

global___QueryHistoricalInfoRequest = QueryHistoricalInfoRequest

@typing_extensions.final
class QueryHistoricalInfoResponse(google.protobuf.message.Message):
    """QueryHistoricalInfoResponse is response type for the Query/HistoricalInfo RPC
    method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HIST_FIELD_NUMBER: builtins.int
    @property
    def hist(self) -> cosmos.staking.v1beta1.staking_pb2.HistoricalInfo:
        """hist defines the historical info at the given height."""
    def __init__(
        self,
        *,
        hist: cosmos.staking.v1beta1.staking_pb2.HistoricalInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["hist", b"hist"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hist", b"hist"]) -> None: ...

global___QueryHistoricalInfoResponse = QueryHistoricalInfoResponse

@typing_extensions.final
class QueryPoolRequest(google.protobuf.message.Message):
    """QueryPoolRequest is request type for the Query/Pool RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___QueryPoolRequest = QueryPoolRequest

@typing_extensions.final
class QueryPoolResponse(google.protobuf.message.Message):
    """QueryPoolResponse is response type for the Query/Pool RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_FIELD_NUMBER: builtins.int
    @property
    def pool(self) -> cosmos.staking.v1beta1.staking_pb2.Pool:
        """pool defines the pool info."""
    def __init__(
        self,
        *,
        pool: cosmos.staking.v1beta1.staking_pb2.Pool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pool", b"pool"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool", b"pool"]) -> None: ...

global___QueryPoolResponse = QueryPoolResponse

@typing_extensions.final
class QueryParamsRequest(google.protobuf.message.Message):
    """QueryParamsRequest is request type for the Query/Params RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___QueryParamsRequest = QueryParamsRequest

@typing_extensions.final
class QueryParamsResponse(google.protobuf.message.Message):
    """QueryParamsResponse is response type for the Query/Params RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> cosmos.staking.v1beta1.staking_pb2.Params:
        """params holds all the parameters of this module."""
    def __init__(
        self,
        *,
        params: cosmos.staking.v1beta1.staking_pb2.Params | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params", b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["params", b"params"]) -> None: ...

global___QueryParamsResponse = QueryParamsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class NetAddress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    IP_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    id: builtins.str
    ip: builtins.str
    port: builtins.int
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        ip: builtins.str = ...,
        port: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "ip", b"ip", "port", b"port"]) -> None: ...

global___NetAddress = NetAddress

@typing_extensions.final
class ProtocolVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    P2P_FIELD_NUMBER: builtins.int
    BLOCK_FIELD_NUMBER: builtins.int
    APP_FIELD_NUMBER: builtins.int
    p2p: builtins.int
    block: builtins.int
    app: builtins.int
    def __init__(
        self,
        *,
        p2p: builtins.int = ...,
        block: builtins.int = ...,
        app: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app", b"app", "block", b"block", "p2p", b"p2p"]) -> None: ...

global___ProtocolVersion = ProtocolVersion

@typing_extensions.final
class DefaultNodeInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROTOCOL_VERSION_FIELD_NUMBER: builtins.int
    DEFAULT_NODE_ID_FIELD_NUMBER: builtins.int
    LISTEN_ADDR_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    CHANNELS_FIELD_NUMBER: builtins.int
    MONIKER_FIELD_NUMBER: builtins.int
    OTHER_FIELD_NUMBER: builtins.int
    @property
    def protocol_version(self) -> global___ProtocolVersion: ...
    default_node_id: builtins.str
    listen_addr: builtins.str
    network: builtins.str
    version: builtins.str
    channels: builtins.bytes
    moniker: builtins.str
    @property
    def other(self) -> global___DefaultNodeInfoOther: ...
    def __init__(
        self,
        *,
        protocol_version: global___ProtocolVersion | None = ...,
        default_node_id: builtins.str = ...,
        listen_addr: builtins.str = ...,
        network: builtins.str = ...,
        version: builtins.str = ...,
        channels: builtins.bytes = ...,
        moniker: builtins.str = ...,
        other: global___DefaultNodeInfoOther | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["other", b"other", "protocol_version", b"protocol_version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["channels", b"channels", "default_node_id", b"default_node_id", "listen_addr", b"listen_addr", "moniker", b"moniker", "network", b"network", "other", b"other", "protocol_version", b"protocol_version", "version", b"version"]) -> None: ...

global___DefaultNodeInfo = DefaultNodeInfo

@typing_extensions.final
class DefaultNodeInfoOther(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TX_INDEX_FIELD_NUMBER: builtins.int
    RPC_ADDRESS_FIELD_NUMBER: builtins.int
    tx_index: builtins.str
    rpc_address: builtins.str
    def __init__(
        self,
        *,
        tx_index: builtins.str = ...,
        rpc_address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["rpc_address", b"rpc_address", "tx_index", b"tx_index"]) -> None: ...

global___DefaultNodeInfoOther = DefaultNodeInfoOther



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import osmosis.lockup.lock_pb2
import osmosis.lockup.params_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ModuleBalanceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ModuleBalanceRequest = ModuleBalanceRequest

@typing_extensions.final
class ModuleBalanceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COINS_FIELD_NUMBER: builtins.int
    @property
    def coins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(
        self,
        *,
        coins: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["coins", b"coins"]) -> None: ...

global___ModuleBalanceResponse = ModuleBalanceResponse

@typing_extensions.final
class ModuleLockedAmountRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ModuleLockedAmountRequest = ModuleLockedAmountRequest

@typing_extensions.final
class ModuleLockedAmountResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COINS_FIELD_NUMBER: builtins.int
    @property
    def coins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(
        self,
        *,
        coins: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["coins", b"coins"]) -> None: ...

global___ModuleLockedAmountResponse = ModuleLockedAmountResponse

@typing_extensions.final
class AccountUnlockableCoinsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OWNER_FIELD_NUMBER: builtins.int
    owner: builtins.str
    def __init__(
        self,
        *,
        owner: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["owner", b"owner"]) -> None: ...

global___AccountUnlockableCoinsRequest = AccountUnlockableCoinsRequest

@typing_extensions.final
class AccountUnlockableCoinsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COINS_FIELD_NUMBER: builtins.int
    @property
    def coins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(
        self,
        *,
        coins: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["coins", b"coins"]) -> None: ...

global___AccountUnlockableCoinsResponse = AccountUnlockableCoinsResponse

@typing_extensions.final
class AccountUnlockingCoinsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OWNER_FIELD_NUMBER: builtins.int
    owner: builtins.str
    def __init__(
        self,
        *,
        owner: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["owner", b"owner"]) -> None: ...

global___AccountUnlockingCoinsRequest = AccountUnlockingCoinsRequest

@typing_extensions.final
class AccountUnlockingCoinsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COINS_FIELD_NUMBER: builtins.int
    @property
    def coins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(
        self,
        *,
        coins: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["coins", b"coins"]) -> None: ...

global___AccountUnlockingCoinsResponse = AccountUnlockingCoinsResponse

@typing_extensions.final
class AccountLockedCoinsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OWNER_FIELD_NUMBER: builtins.int
    owner: builtins.str
    def __init__(
        self,
        *,
        owner: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["owner", b"owner"]) -> None: ...

global___AccountLockedCoinsRequest = AccountLockedCoinsRequest

@typing_extensions.final
class AccountLockedCoinsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COINS_FIELD_NUMBER: builtins.int
    @property
    def coins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(
        self,
        *,
        coins: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["coins", b"coins"]) -> None: ...

global___AccountLockedCoinsResponse = AccountLockedCoinsResponse

@typing_extensions.final
class AccountLockedPastTimeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OWNER_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    owner: builtins.str
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        owner: builtins.str = ...,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["owner", b"owner", "timestamp", b"timestamp"]) -> None: ...

global___AccountLockedPastTimeRequest = AccountLockedPastTimeRequest

@typing_extensions.final
class AccountLockedPastTimeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCKS_FIELD_NUMBER: builtins.int
    @property
    def locks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[osmosis.lockup.lock_pb2.PeriodLock]: ...
    def __init__(
        self,
        *,
        locks: collections.abc.Iterable[osmosis.lockup.lock_pb2.PeriodLock] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["locks", b"locks"]) -> None: ...

global___AccountLockedPastTimeResponse = AccountLockedPastTimeResponse

@typing_extensions.final
class AccountLockedPastTimeNotUnlockingOnlyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OWNER_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    owner: builtins.str
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        owner: builtins.str = ...,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["owner", b"owner", "timestamp", b"timestamp"]) -> None: ...

global___AccountLockedPastTimeNotUnlockingOnlyRequest = AccountLockedPastTimeNotUnlockingOnlyRequest

@typing_extensions.final
class AccountLockedPastTimeNotUnlockingOnlyResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCKS_FIELD_NUMBER: builtins.int
    @property
    def locks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[osmosis.lockup.lock_pb2.PeriodLock]: ...
    def __init__(
        self,
        *,
        locks: collections.abc.Iterable[osmosis.lockup.lock_pb2.PeriodLock] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["locks", b"locks"]) -> None: ...

global___AccountLockedPastTimeNotUnlockingOnlyResponse = AccountLockedPastTimeNotUnlockingOnlyResponse

@typing_extensions.final
class AccountUnlockedBeforeTimeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OWNER_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    owner: builtins.str
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        owner: builtins.str = ...,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["owner", b"owner", "timestamp", b"timestamp"]) -> None: ...

global___AccountUnlockedBeforeTimeRequest = AccountUnlockedBeforeTimeRequest

@typing_extensions.final
class AccountUnlockedBeforeTimeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCKS_FIELD_NUMBER: builtins.int
    @property
    def locks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[osmosis.lockup.lock_pb2.PeriodLock]: ...
    def __init__(
        self,
        *,
        locks: collections.abc.Iterable[osmosis.lockup.lock_pb2.PeriodLock] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["locks", b"locks"]) -> None: ...

global___AccountUnlockedBeforeTimeResponse = AccountUnlockedBeforeTimeResponse

@typing_extensions.final
class AccountLockedPastTimeDenomRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OWNER_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    DENOM_FIELD_NUMBER: builtins.int
    owner: builtins.str
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    denom: builtins.str
    def __init__(
        self,
        *,
        owner: builtins.str = ...,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        denom: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["denom", b"denom", "owner", b"owner", "timestamp", b"timestamp"]) -> None: ...

global___AccountLockedPastTimeDenomRequest = AccountLockedPastTimeDenomRequest

@typing_extensions.final
class AccountLockedPastTimeDenomResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCKS_FIELD_NUMBER: builtins.int
    @property
    def locks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[osmosis.lockup.lock_pb2.PeriodLock]: ...
    def __init__(
        self,
        *,
        locks: collections.abc.Iterable[osmosis.lockup.lock_pb2.PeriodLock] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["locks", b"locks"]) -> None: ...

global___AccountLockedPastTimeDenomResponse = AccountLockedPastTimeDenomResponse

@typing_extensions.final
class LockedDenomRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DENOM_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    denom: builtins.str
    @property
    def duration(self) -> google.protobuf.duration_pb2.Duration: ...
    def __init__(
        self,
        *,
        denom: builtins.str = ...,
        duration: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["duration", b"duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["denom", b"denom", "duration", b"duration"]) -> None: ...

global___LockedDenomRequest = LockedDenomRequest

@typing_extensions.final
class LockedDenomResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AMOUNT_FIELD_NUMBER: builtins.int
    amount: builtins.str
    def __init__(
        self,
        *,
        amount: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount", b"amount"]) -> None: ...

global___LockedDenomResponse = LockedDenomResponse

@typing_extensions.final
class LockedRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCK_ID_FIELD_NUMBER: builtins.int
    lock_id: builtins.int
    def __init__(
        self,
        *,
        lock_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["lock_id", b"lock_id"]) -> None: ...

global___LockedRequest = LockedRequest

@typing_extensions.final
class LockedResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCK_FIELD_NUMBER: builtins.int
    @property
    def lock(self) -> osmosis.lockup.lock_pb2.PeriodLock: ...
    def __init__(
        self,
        *,
        lock: osmosis.lockup.lock_pb2.PeriodLock | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["lock", b"lock"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["lock", b"lock"]) -> None: ...

global___LockedResponse = LockedResponse

@typing_extensions.final
class SyntheticLockupsByLockupIDRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCK_ID_FIELD_NUMBER: builtins.int
    lock_id: builtins.int
    def __init__(
        self,
        *,
        lock_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["lock_id", b"lock_id"]) -> None: ...

global___SyntheticLockupsByLockupIDRequest = SyntheticLockupsByLockupIDRequest

@typing_extensions.final
class SyntheticLockupsByLockupIDResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SYNTHETIC_LOCKS_FIELD_NUMBER: builtins.int
    @property
    def synthetic_locks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[osmosis.lockup.lock_pb2.SyntheticLock]: ...
    def __init__(
        self,
        *,
        synthetic_locks: collections.abc.Iterable[osmosis.lockup.lock_pb2.SyntheticLock] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["synthetic_locks", b"synthetic_locks"]) -> None: ...

global___SyntheticLockupsByLockupIDResponse = SyntheticLockupsByLockupIDResponse

@typing_extensions.final
class AccountLockedLongerDurationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OWNER_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    owner: builtins.str
    @property
    def duration(self) -> google.protobuf.duration_pb2.Duration: ...
    def __init__(
        self,
        *,
        owner: builtins.str = ...,
        duration: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["duration", b"duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["duration", b"duration", "owner", b"owner"]) -> None: ...

global___AccountLockedLongerDurationRequest = AccountLockedLongerDurationRequest

@typing_extensions.final
class AccountLockedLongerDurationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCKS_FIELD_NUMBER: builtins.int
    @property
    def locks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[osmosis.lockup.lock_pb2.PeriodLock]: ...
    def __init__(
        self,
        *,
        locks: collections.abc.Iterable[osmosis.lockup.lock_pb2.PeriodLock] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["locks", b"locks"]) -> None: ...

global___AccountLockedLongerDurationResponse = AccountLockedLongerDurationResponse

@typing_extensions.final
class AccountLockedDurationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OWNER_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    owner: builtins.str
    @property
    def duration(self) -> google.protobuf.duration_pb2.Duration: ...
    def __init__(
        self,
        *,
        owner: builtins.str = ...,
        duration: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["duration", b"duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["duration", b"duration", "owner", b"owner"]) -> None: ...

global___AccountLockedDurationRequest = AccountLockedDurationRequest

@typing_extensions.final
class AccountLockedDurationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCKS_FIELD_NUMBER: builtins.int
    @property
    def locks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[osmosis.lockup.lock_pb2.PeriodLock]: ...
    def __init__(
        self,
        *,
        locks: collections.abc.Iterable[osmosis.lockup.lock_pb2.PeriodLock] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["locks", b"locks"]) -> None: ...

global___AccountLockedDurationResponse = AccountLockedDurationResponse

@typing_extensions.final
class AccountLockedLongerDurationNotUnlockingOnlyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OWNER_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    owner: builtins.str
    @property
    def duration(self) -> google.protobuf.duration_pb2.Duration: ...
    def __init__(
        self,
        *,
        owner: builtins.str = ...,
        duration: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["duration", b"duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["duration", b"duration", "owner", b"owner"]) -> None: ...

global___AccountLockedLongerDurationNotUnlockingOnlyRequest = AccountLockedLongerDurationNotUnlockingOnlyRequest

@typing_extensions.final
class AccountLockedLongerDurationNotUnlockingOnlyResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCKS_FIELD_NUMBER: builtins.int
    @property
    def locks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[osmosis.lockup.lock_pb2.PeriodLock]: ...
    def __init__(
        self,
        *,
        locks: collections.abc.Iterable[osmosis.lockup.lock_pb2.PeriodLock] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["locks", b"locks"]) -> None: ...

global___AccountLockedLongerDurationNotUnlockingOnlyResponse = AccountLockedLongerDurationNotUnlockingOnlyResponse

@typing_extensions.final
class AccountLockedLongerDurationDenomRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OWNER_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    DENOM_FIELD_NUMBER: builtins.int
    owner: builtins.str
    @property
    def duration(self) -> google.protobuf.duration_pb2.Duration: ...
    denom: builtins.str
    def __init__(
        self,
        *,
        owner: builtins.str = ...,
        duration: google.protobuf.duration_pb2.Duration | None = ...,
        denom: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["duration", b"duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["denom", b"denom", "duration", b"duration", "owner", b"owner"]) -> None: ...

global___AccountLockedLongerDurationDenomRequest = AccountLockedLongerDurationDenomRequest

@typing_extensions.final
class AccountLockedLongerDurationDenomResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCKS_FIELD_NUMBER: builtins.int
    @property
    def locks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[osmosis.lockup.lock_pb2.PeriodLock]: ...
    def __init__(
        self,
        *,
        locks: collections.abc.Iterable[osmosis.lockup.lock_pb2.PeriodLock] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["locks", b"locks"]) -> None: ...

global___AccountLockedLongerDurationDenomResponse = AccountLockedLongerDurationDenomResponse

@typing_extensions.final
class QueryParamsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___QueryParamsRequest = QueryParamsRequest

@typing_extensions.final
class QueryParamsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> osmosis.lockup.params_pb2.Params: ...
    def __init__(
        self,
        *,
        params: osmosis.lockup.params_pb2.Params | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params", b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["params", b"params"]) -> None: ...

global___QueryParamsResponse = QueryParamsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import osmosis.gamm.pool_models.stableswap.tx_pb2

class MsgStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    CreateStableswapPool: grpc.UnaryUnaryMultiCallable[
        osmosis.gamm.pool_models.stableswap.tx_pb2.MsgCreateStableswapPool,
        osmosis.gamm.pool_models.stableswap.tx_pb2.MsgCreateStableswapPoolResponse,
    ]
    StableSwapAdjustScalingFactors: grpc.UnaryUnaryMultiCallable[
        osmosis.gamm.pool_models.stableswap.tx_pb2.MsgStableSwapAdjustScalingFactors,
        osmosis.gamm.pool_models.stableswap.tx_pb2.MsgStableSwapAdjustScalingFactorsResponse,
    ]

class MsgServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def CreateStableswapPool(
        self,
        request: osmosis.gamm.pool_models.stableswap.tx_pb2.MsgCreateStableswapPool,
        context: grpc.ServicerContext,
    ) -> osmosis.gamm.pool_models.stableswap.tx_pb2.MsgCreateStableswapPoolResponse: ...
    @abc.abstractmethod
    def StableSwapAdjustScalingFactors(
        self,
        request: osmosis.gamm.pool_models.stableswap.tx_pb2.MsgStableSwapAdjustScalingFactors,
        context: grpc.ServicerContext,
    ) -> osmosis.gamm.pool_models.stableswap.tx_pb2.MsgStableSwapAdjustScalingFactorsResponse: ...

def add_MsgServicer_to_server(servicer: MsgServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Since: cosmos-sdk 0.43"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class EventGrant(google.protobuf.message.Message):
    """EventGrant is emitted on Msg/Grant"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_TYPE_URL_FIELD_NUMBER: builtins.int
    GRANTER_FIELD_NUMBER: builtins.int
    GRANTEE_FIELD_NUMBER: builtins.int
    msg_type_url: builtins.str
    """Msg type URL for which an autorization is granted"""
    granter: builtins.str
    """Granter account address"""
    grantee: builtins.str
    """Grantee account address"""
    def __init__(
        self,
        *,
        msg_type_url: builtins.str = ...,
        granter: builtins.str = ...,
        grantee: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["grantee", b"grantee", "granter", b"granter", "msg_type_url", b"msg_type_url"]) -> None: ...

global___EventGrant = EventGrant

@typing_extensions.final
class EventRevoke(google.protobuf.message.Message):
    """EventRevoke is emitted on Msg/Revoke"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_TYPE_URL_FIELD_NUMBER: builtins.int
    GRANTER_FIELD_NUMBER: builtins.int
    GRANTEE_FIELD_NUMBER: builtins.int
    msg_type_url: builtins.str
    """Msg type URL for which an autorization is revoked"""
    granter: builtins.str
    """Granter account address"""
    grantee: builtins.str
    """Grantee account address"""
    def __init__(
        self,
        *,
        msg_type_url: builtins.str = ...,
        granter: builtins.str = ...,
        grantee: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["grantee", b"grantee", "granter", b"granter", "msg_type_url", b"msg_type_url"]) -> None: ...

global___EventRevoke = EventRevoke



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import osmosis.superfluid.tx_pb2

class MsgStub:
    """Msg defines the Msg service."""

    def __init__(self, channel: grpc.Channel) -> None: ...
    SuperfluidDelegate: grpc.UnaryUnaryMultiCallable[
        osmosis.superfluid.tx_pb2.MsgSuperfluidDelegate,
        osmosis.superfluid.tx_pb2.MsgSuperfluidDelegateResponse,
    ]
    """Execute superfluid delegation for a lockup"""
    SuperfluidUndelegate: grpc.UnaryUnaryMultiCallable[
        osmosis.superfluid.tx_pb2.MsgSuperfluidUndelegate,
        osmosis.superfluid.tx_pb2.MsgSuperfluidUndelegateResponse,
    ]
    """Execute superfluid undelegation for a lockup"""
    SuperfluidUnbondLock: grpc.UnaryUnaryMultiCallable[
        osmosis.superfluid.tx_pb2.MsgSuperfluidUnbondLock,
        osmosis.superfluid.tx_pb2.MsgSuperfluidUnbondLockResponse,
    ]
    """Execute superfluid redelegation for a lockup
    rpc SuperfluidRedelegate(MsgSuperfluidRedelegate) returns
    (MsgSuperfluidRedelegateResponse);

    For a given lock that is being superfluidly undelegated,
    also unbond the underlying lock.
    """
    LockAndSuperfluidDelegate: grpc.UnaryUnaryMultiCallable[
        osmosis.superfluid.tx_pb2.MsgLockAndSuperfluidDelegate,
        osmosis.superfluid.tx_pb2.MsgLockAndSuperfluidDelegateResponse,
    ]
    """Execute lockup lock and superfluid delegation in a single msg"""
    UnPoolWhitelistedPool: grpc.UnaryUnaryMultiCallable[
        osmosis.superfluid.tx_pb2.MsgUnPoolWhitelistedPool,
        osmosis.superfluid.tx_pb2.MsgUnPoolWhitelistedPoolResponse,
    ]

class MsgServicer(metaclass=abc.ABCMeta):
    """Msg defines the Msg service."""

    @abc.abstractmethod
    def SuperfluidDelegate(
        self,
        request: osmosis.superfluid.tx_pb2.MsgSuperfluidDelegate,
        context: grpc.ServicerContext,
    ) -> osmosis.superfluid.tx_pb2.MsgSuperfluidDelegateResponse:
        """Execute superfluid delegation for a lockup"""
    @abc.abstractmethod
    def SuperfluidUndelegate(
        self,
        request: osmosis.superfluid.tx_pb2.MsgSuperfluidUndelegate,
        context: grpc.ServicerContext,
    ) -> osmosis.superfluid.tx_pb2.MsgSuperfluidUndelegateResponse:
        """Execute superfluid undelegation for a lockup"""
    @abc.abstractmethod
    def SuperfluidUnbondLock(
        self,
        request: osmosis.superfluid.tx_pb2.MsgSuperfluidUnbondLock,
        context: grpc.ServicerContext,
    ) -> osmosis.superfluid.tx_pb2.MsgSuperfluidUnbondLockResponse:
        """Execute superfluid redelegation for a lockup
        rpc SuperfluidRedelegate(MsgSuperfluidRedelegate) returns
        (MsgSuperfluidRedelegateResponse);

        For a given lock that is being superfluidly undelegated,
        also unbond the underlying lock.
        """
    @abc.abstractmethod
    def LockAndSuperfluidDelegate(
        self,
        request: osmosis.superfluid.tx_pb2.MsgLockAndSuperfluidDelegate,
        context: grpc.ServicerContext,
    ) -> osmosis.superfluid.tx_pb2.MsgLockAndSuperfluidDelegateResponse:
        """Execute lockup lock and superfluid delegation in a single msg"""
    @abc.abstractmethod
    def UnPoolWhitelistedPool(
        self,
        request: osmosis.superfluid.tx_pb2.MsgUnPoolWhitelistedPool,
        context: grpc.ServicerContext,
    ) -> osmosis.superfluid.tx_pb2.MsgUnPoolWhitelistedPoolResponse: ...

def add_MsgServicer_to_server(servicer: MsgServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
this is a legacy package that requires additional migration logic
in order to use the correct packge. Decision made to use legacy package path
until clear steps for migration logic and the unknowns for state breaking are
investigated for changing proto package.
"""



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from osmosis.txfees.v1beta1 import query_pb2 as osmosis_dot_txfees_dot_v1beta1_dot_query__pb2


class QueryStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.FeeTokens = channel.unary_unary(
                '/osmosis.txfees.v1beta1.Query/FeeTokens',
                request_serializer=osmosis_dot_txfees_dot_v1beta1_dot_query__pb2.QueryFeeTokensRequest.SerializeToString,
                response_deserializer=osmosis_dot_txfees_dot_v1beta1_dot_query__pb2.QueryFeeTokensResponse.FromString,
                )
        self.DenomSpotPrice = channel.unary_unary(
                '/osmosis.txfees.v1beta1.Query/DenomSpotPrice',
                request_serializer=osmosis_dot_txfees_dot_v1beta1_dot_query__pb2.QueryDenomSpotPriceRequest.SerializeToString,
                response_deserializer=osmosis_dot_txfees_dot_v1beta1_dot_query__pb2.QueryDenomSpotPriceResponse.FromString,
                )
        self.DenomPoolId = channel.unary_unary(
                '/osmosis.txfees.v1beta1.Query/DenomPoolId',
                request_serializer=osmosis_dot_txfees_dot_v1beta1_dot_query__pb2.QueryDenomPoolIdRequest.SerializeToString,
                response_deserializer=osmosis_dot_txfees_dot_v1beta1_dot_query__pb2.QueryDenomPoolIdResponse.FromString,
                )
        self.BaseDenom = channel.unary_unary(
                '/osmosis.txfees.v1beta1.Query/BaseDenom',
                request_serializer=osmosis_dot_txfees_dot_v1beta1_dot_query__pb2.QueryBaseDenomRequest.SerializeToString,
                response_deserializer=osmosis_dot_txfees_dot_v1beta1_dot_query__pb2.QueryBaseDenomResponse.FromString,
                )


class QueryServicer(object):
    """Missing associated documentation comment in .proto file."""

    def FeeTokens(self, request, context):
        """FeeTokens returns a list of all the whitelisted fee tokens and their
        corresponding pools. It does not include the BaseDenom, which has its own
        query endpoint
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DenomSpotPrice(self, request, context):
        """DenomSpotPrice returns all spot prices by each registered token denom.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DenomPoolId(self, request, context):
        """Returns the poolID for a specified denom input.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BaseDenom(self, request, context):
        """Returns a list of all base denom tokens and their corresponding pools.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'FeeTokens': grpc.unary_unary_rpc_method_handler(
                    servicer.FeeTokens,
                    request_deserializer=osmosis_dot_txfees_dot_v1beta1_dot_query__pb2.QueryFeeTokensRequest.FromString,
                    response_serializer=osmosis_dot_txfees_dot_v1beta1_dot_query__pb2.QueryFeeTokensResponse.SerializeToString,
            ),
            'DenomSpotPrice': grpc.unary_unary_rpc_method_handler(
                    servicer.DenomSpotPrice,
                    request_deserializer=osmosis_dot_txfees_dot_v1beta1_dot_query__pb2.QueryDenomSpotPriceRequest.FromString,
                    response_serializer=osmosis_dot_txfees_dot_v1beta1_dot_query__pb2.QueryDenomSpotPriceResponse.SerializeToString,
            ),
            'DenomPoolId': grpc.unary_unary_rpc_method_handler(
                    servicer.DenomPoolId,
                    request_deserializer=osmosis_dot_txfees_dot_v1beta1_dot_query__pb2.QueryDenomPoolIdRequest.FromString,
                    response_serializer=osmosis_dot_txfees_dot_v1beta1_dot_query__pb2.QueryDenomPoolIdResponse.SerializeToString,
            ),
            'BaseDenom': grpc.unary_unary_rpc_method_handler(
                    servicer.BaseDenom,
                    request_deserializer=osmosis_dot_txfees_dot_v1beta1_dot_query__pb2.QueryBaseDenomRequest.FromString,
                    response_serializer=osmosis_dot_txfees_dot_v1beta1_dot_query__pb2.QueryBaseDenomResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'osmosis.txfees.v1beta1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def FeeTokens(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.txfees.v1beta1.Query/FeeTokens',
            osmosis_dot_txfees_dot_v1beta1_dot_query__pb2.QueryFeeTokensRequest.SerializeToString,
            osmosis_dot_txfees_dot_v1beta1_dot_query__pb2.QueryFeeTokensResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DenomSpotPrice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.txfees.v1beta1.Query/DenomSpotPrice',
            osmosis_dot_txfees_dot_v1beta1_dot_query__pb2.QueryDenomSpotPriceRequest.SerializeToString,
            osmosis_dot_txfees_dot_v1beta1_dot_query__pb2.QueryDenomSpotPriceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DenomPoolId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.txfees.v1beta1.Query/DenomPoolId',
            osmosis_dot_txfees_dot_v1beta1_dot_query__pb2.QueryDenomPoolIdRequest.SerializeToString,
            osmosis_dot_txfees_dot_v1beta1_dot_query__pb2.QueryDenomPoolIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BaseDenom(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.txfees.v1beta1.Query/BaseDenom',
            osmosis_dot_txfees_dot_v1beta1_dot_query__pb2.QueryBaseDenomRequest.SerializeToString,
            osmosis_dot_txfees_dot_v1beta1_dot_query__pb2.QueryBaseDenomResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/superfluid/v1beta1/gov.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from osmosis.superfluid import superfluid_pb2 as osmosis_dot_superfluid_dot_superfluid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$osmosis/superfluid/v1beta1/gov.proto\x12\x1aosmosis.superfluid.v1beta1\x1a\x14gogoproto/gogo.proto\x1a#osmosis/superfluid/superfluid.proto\"\x8a\x01\n\x1bSetSuperfluidAssetsProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x39\n\x06\x61ssets\x18\x03 \x03(\x0b\x32#.osmosis.superfluid.SuperfluidAssetB\x04\xc8\xde\x1f\x00:\x0c\xe8\xa0\x1f\x01\x88\xa0\x1f\x00\x98\xa0\x1f\x00\"s\n\x1eRemoveSuperfluidAssetsProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x1f\n\x17superfluid_asset_denoms\x18\x03 \x03(\t:\x0c\xe8\xa0\x1f\x01\x88\xa0\x1f\x00\x98\xa0\x1f\x00\"t\n\x1dUpdateUnpoolWhiteListProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0b\n\x03ids\x18\x03 \x03(\x04\x12\x14\n\x0cis_overwrite\x18\x04 \x01(\x08:\x0c\xe8\xa0\x1f\x01\x88\xa0\x1f\x00\x98\xa0\x1f\x00\x42\x38Z6github.com/osmosis-labs/osmosis/v14/x/superfluid/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.superfluid.v1beta1.gov_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z6github.com/osmosis-labs/osmosis/v14/x/superfluid/types'
  _SETSUPERFLUIDASSETSPROPOSAL.fields_by_name['assets']._options = None
  _SETSUPERFLUIDASSETSPROPOSAL.fields_by_name['assets']._serialized_options = b'\310\336\037\000'
  _SETSUPERFLUIDASSETSPROPOSAL._options = None
  _SETSUPERFLUIDASSETSPROPOSAL._serialized_options = b'\350\240\037\001\210\240\037\000\230\240\037\000'
  _REMOVESUPERFLUIDASSETSPROPOSAL._options = None
  _REMOVESUPERFLUIDASSETSPROPOSAL._serialized_options = b'\350\240\037\001\210\240\037\000\230\240\037\000'
  _UPDATEUNPOOLWHITELISTPROPOSAL._options = None
  _UPDATEUNPOOLWHITELISTPROPOSAL._serialized_options = b'\350\240\037\001\210\240\037\000\230\240\037\000'
  _SETSUPERFLUIDASSETSPROPOSAL._serialized_start=128
  _SETSUPERFLUIDASSETSPROPOSAL._serialized_end=266
  _REMOVESUPERFLUIDASSETSPROPOSAL._serialized_start=268
  _REMOVESUPERFLUIDASSETSPROPOSAL._serialized_end=383
  _UPDATEUNPOOLWHITELISTPROPOSAL._serialized_start=385
  _UPDATEUNPOOLWHITELISTPROPOSAL._serialized_end=501
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.bank.v1beta1.bank_pb2
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class MsgSend(google.protobuf.message.Message):
    """MsgSend represents a message to send coins from one account to another."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FROM_ADDRESS_FIELD_NUMBER: builtins.int
    TO_ADDRESS_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    from_address: builtins.str
    to_address: builtins.str
    @property
    def amount(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(
        self,
        *,
        from_address: builtins.str = ...,
        to_address: builtins.str = ...,
        amount: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount", b"amount", "from_address", b"from_address", "to_address", b"to_address"]) -> None: ...

global___MsgSend = MsgSend

@typing_extensions.final
class MsgSendResponse(google.protobuf.message.Message):
    """MsgSendResponse defines the Msg/Send response type."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MsgSendResponse = MsgSendResponse

@typing_extensions.final
class MsgMultiSend(google.protobuf.message.Message):
    """MsgMultiSend represents an arbitrary multi-in, multi-out send message."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INPUTS_FIELD_NUMBER: builtins.int
    OUTPUTS_FIELD_NUMBER: builtins.int
    @property
    def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.bank.v1beta1.bank_pb2.Input]: ...
    @property
    def outputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.bank.v1beta1.bank_pb2.Output]: ...
    def __init__(
        self,
        *,
        inputs: collections.abc.Iterable[cosmos.bank.v1beta1.bank_pb2.Input] | None = ...,
        outputs: collections.abc.Iterable[cosmos.bank.v1beta1.bank_pb2.Output] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["inputs", b"inputs", "outputs", b"outputs"]) -> None: ...

global___MsgMultiSend = MsgMultiSend

@typing_extensions.final
class MsgMultiSendResponse(google.protobuf.message.Message):
    """MsgMultiSendResponse defines the Msg/MultiSend response type."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MsgMultiSendResponse = MsgMultiSendResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class App(google.protobuf.message.Message):
    """App includes the protocol and software version for the application.
    This information is included in ResponseInfo. The App.Protocol can be
    updated in ResponseEndBlock.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROTOCOL_FIELD_NUMBER: builtins.int
    SOFTWARE_FIELD_NUMBER: builtins.int
    protocol: builtins.int
    software: builtins.str
    def __init__(
        self,
        *,
        protocol: builtins.int = ...,
        software: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["protocol", b"protocol", "software", b"software"]) -> None: ...

global___App = App

@typing_extensions.final
class Consensus(google.protobuf.message.Message):
    """Consensus captures the consensus rules for processing a block in the blockchain,
    including all blockchain data structures and the rules of the application's
    state transition machine.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BLOCK_FIELD_NUMBER: builtins.int
    APP_FIELD_NUMBER: builtins.int
    block: builtins.int
    app: builtins.int
    def __init__(
        self,
        *,
        block: builtins.int = ...,
        app: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app", b"app", "block", b"block"]) -> None: ...

global___Consensus = Consensus



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.auth.v1beta1.auth_pb2
import cosmos.base.query.v1beta1.pagination_pb2
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class QueryAccountsRequest(google.protobuf.message.Message):
    """QueryAccountsRequest is the request type for the Query/Accounts RPC method.

    Since: cosmos-sdk 0.43
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """pagination defines an optional pagination for the request."""
    def __init__(
        self,
        *,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> None: ...

global___QueryAccountsRequest = QueryAccountsRequest

@typing_extensions.final
class QueryAccountsResponse(google.protobuf.message.Message):
    """QueryAccountsResponse is the response type for the Query/Accounts RPC method.

    Since: cosmos-sdk 0.43
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNTS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def accounts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.any_pb2.Any]:
        """accounts are the existing accounts"""
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """pagination defines the pagination in the response."""
    def __init__(
        self,
        *,
        accounts: collections.abc.Iterable[google.protobuf.any_pb2.Any] | None = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accounts", b"accounts", "pagination", b"pagination"]) -> None: ...

global___QueryAccountsResponse = QueryAccountsResponse

@typing_extensions.final
class QueryAccountRequest(google.protobuf.message.Message):
    """QueryAccountRequest is the request type for the Query/Account RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    address: builtins.str
    """address defines the address to query for."""
    def __init__(
        self,
        *,
        address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["address", b"address"]) -> None: ...

global___QueryAccountRequest = QueryAccountRequest

@typing_extensions.final
class QueryAccountResponse(google.protobuf.message.Message):
    """QueryAccountResponse is the response type for the Query/Account RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_FIELD_NUMBER: builtins.int
    @property
    def account(self) -> google.protobuf.any_pb2.Any:
        """account defines the account of the corresponding address."""
    def __init__(
        self,
        *,
        account: google.protobuf.any_pb2.Any | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["account", b"account"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account", b"account"]) -> None: ...

global___QueryAccountResponse = QueryAccountResponse

@typing_extensions.final
class QueryParamsRequest(google.protobuf.message.Message):
    """QueryParamsRequest is the request type for the Query/Params RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___QueryParamsRequest = QueryParamsRequest

@typing_extensions.final
class QueryParamsResponse(google.protobuf.message.Message):
    """QueryParamsResponse is the response type for the Query/Params RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> cosmos.auth.v1beta1.auth_pb2.Params:
        """params defines the parameters of the module."""
    def __init__(
        self,
        *,
        params: cosmos.auth.v1beta1.auth_pb2.Params | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params", b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["params", b"params"]) -> None: ...

global___QueryParamsResponse = QueryParamsResponse

@typing_extensions.final
class QueryModuleAccountsRequest(google.protobuf.message.Message):
    """QueryModuleAccountsRequest is the request type for the Query/ModuleAccounts RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___QueryModuleAccountsRequest = QueryModuleAccountsRequest

@typing_extensions.final
class QueryModuleAccountsResponse(google.protobuf.message.Message):
    """QueryModuleAccountsResponse is the response type for the Query/ModuleAccounts RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNTS_FIELD_NUMBER: builtins.int
    @property
    def accounts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.any_pb2.Any]: ...
    def __init__(
        self,
        *,
        accounts: collections.abc.Iterable[google.protobuf.any_pb2.Any] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["accounts", b"accounts"]) -> None: ...

global___QueryModuleAccountsResponse = QueryModuleAccountsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import osmosis.gamm.pool_models.stableswap.stableswap_pool_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class MsgCreateStableswapPool(google.protobuf.message.Message):
    """===================== MsgCreatePool"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENDER_FIELD_NUMBER: builtins.int
    POOL_PARAMS_FIELD_NUMBER: builtins.int
    INITIAL_POOL_LIQUIDITY_FIELD_NUMBER: builtins.int
    SCALING_FACTORS_FIELD_NUMBER: builtins.int
    FUTURE_POOL_GOVERNOR_FIELD_NUMBER: builtins.int
    SCALING_FACTOR_CONTROLLER_FIELD_NUMBER: builtins.int
    sender: builtins.str
    @property
    def pool_params(self) -> osmosis.gamm.pool_models.stableswap.stableswap_pool_pb2.PoolParams: ...
    @property
    def initial_pool_liquidity(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    @property
    def scaling_factors(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    future_pool_governor: builtins.str
    scaling_factor_controller: builtins.str
    def __init__(
        self,
        *,
        sender: builtins.str = ...,
        pool_params: osmosis.gamm.pool_models.stableswap.stableswap_pool_pb2.PoolParams | None = ...,
        initial_pool_liquidity: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
        scaling_factors: collections.abc.Iterable[builtins.int] | None = ...,
        future_pool_governor: builtins.str = ...,
        scaling_factor_controller: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pool_params", b"pool_params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["future_pool_governor", b"future_pool_governor", "initial_pool_liquidity", b"initial_pool_liquidity", "pool_params", b"pool_params", "scaling_factor_controller", b"scaling_factor_controller", "scaling_factors", b"scaling_factors", "sender", b"sender"]) -> None: ...

global___MsgCreateStableswapPool = MsgCreateStableswapPool

@typing_extensions.final
class MsgCreateStableswapPoolResponse(google.protobuf.message.Message):
    """Returns a poolID with custom poolName."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_ID_FIELD_NUMBER: builtins.int
    pool_id: builtins.int
    def __init__(
        self,
        *,
        pool_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool_id", b"pool_id"]) -> None: ...

global___MsgCreateStableswapPoolResponse = MsgCreateStableswapPoolResponse

@typing_extensions.final
class MsgStableSwapAdjustScalingFactors(google.protobuf.message.Message):
    """Sender must be the pool's scaling_factor_governor in order for the tx to
    succeed. Adjusts stableswap scaling factors.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENDER_FIELD_NUMBER: builtins.int
    POOL_ID_FIELD_NUMBER: builtins.int
    SCALING_FACTORS_FIELD_NUMBER: builtins.int
    sender: builtins.str
    pool_id: builtins.int
    @property
    def scaling_factors(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        sender: builtins.str = ...,
        pool_id: builtins.int = ...,
        scaling_factors: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool_id", b"pool_id", "scaling_factors", b"scaling_factors", "sender", b"sender"]) -> None: ...

global___MsgStableSwapAdjustScalingFactors = MsgStableSwapAdjustScalingFactors

@typing_extensions.final
class MsgStableSwapAdjustScalingFactorsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MsgStableSwapAdjustScalingFactorsResponse = MsgStableSwapAdjustScalingFactorsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Plan(google.protobuf.message.Message):
    """Plan specifies information about a planned upgrade and when it should occur."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    INFO_FIELD_NUMBER: builtins.int
    UPGRADED_CLIENT_STATE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Sets the name for the upgrade. This name will be used by the upgraded
    version of the software to apply any special "on-upgrade" commands during
    the first BeginBlock method after the upgrade is applied. It is also used
    to detect whether a software version can handle a given upgrade. If no
    upgrade handler with this name has been set in the software, it will be
    assumed that the software is out-of-date when the upgrade Time or Height is
    reached and the software will exit.
    """
    @property
    def time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Deprecated: Time based upgrades have been deprecated. Time based upgrade logic
        has been removed from the SDK.
        If this field is not empty, an error will be thrown.
        """
    height: builtins.int
    """The height at which the upgrade must be performed.
    Only used if Time is not set.
    """
    info: builtins.str
    """Any application specific upgrade info to be included on-chain
    such as a git commit that validators could automatically upgrade to
    """
    @property
    def upgraded_client_state(self) -> google.protobuf.any_pb2.Any:
        """Deprecated: UpgradedClientState field has been deprecated. IBC upgrade logic has been
        moved to the IBC module in the sub module 02-client.
        If this field is not empty, an error will be thrown.
        """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        height: builtins.int = ...,
        info: builtins.str = ...,
        upgraded_client_state: google.protobuf.any_pb2.Any | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["time", b"time", "upgraded_client_state", b"upgraded_client_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["height", b"height", "info", b"info", "name", b"name", "time", b"time", "upgraded_client_state", b"upgraded_client_state"]) -> None: ...

global___Plan = Plan

@typing_extensions.final
class SoftwareUpgradeProposal(google.protobuf.message.Message):
    """SoftwareUpgradeProposal is a gov Content type for initiating a software
    upgrade.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PLAN_FIELD_NUMBER: builtins.int
    title: builtins.str
    description: builtins.str
    @property
    def plan(self) -> global___Plan: ...
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        description: builtins.str = ...,
        plan: global___Plan | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["plan", b"plan"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "plan", b"plan", "title", b"title"]) -> None: ...

global___SoftwareUpgradeProposal = SoftwareUpgradeProposal

@typing_extensions.final
class CancelSoftwareUpgradeProposal(google.protobuf.message.Message):
    """CancelSoftwareUpgradeProposal is a gov Content type for cancelling a software
    upgrade.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    title: builtins.str
    description: builtins.str
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "title", b"title"]) -> None: ...

global___CancelSoftwareUpgradeProposal = CancelSoftwareUpgradeProposal

@typing_extensions.final
class ModuleVersion(google.protobuf.message.Message):
    """ModuleVersion specifies a module and its consensus version.

    Since: cosmos-sdk 0.43
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    name: builtins.str
    """name of the app module"""
    version: builtins.int
    """consensus version of the app module"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        version: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "version", b"version"]) -> None: ...

global___ModuleVersion = ModuleVersion



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Capability(google.protobuf.message.Message):
    """Capability defines an implementation of an object capability. The index
    provided to a Capability must be globally unique.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INDEX_FIELD_NUMBER: builtins.int
    index: builtins.int
    def __init__(
        self,
        *,
        index: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["index", b"index"]) -> None: ...

global___Capability = Capability

@typing_extensions.final
class Owner(google.protobuf.message.Message):
    """Owner defines a single capability owner. An owner is defined by the name of
    capability and the module name.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODULE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    module: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        module: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["module", b"module", "name", b"name"]) -> None: ...

global___Owner = Owner

@typing_extensions.final
class CapabilityOwners(google.protobuf.message.Message):
    """CapabilityOwners defines a set of owners of a single Capability. The set of
    owners must be unique.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OWNERS_FIELD_NUMBER: builtins.int
    @property
    def owners(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Owner]: ...
    def __init__(
        self,
        *,
        owners: collections.abc.Iterable[global___Owner] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["owners", b"owners"]) -> None: ...

global___CapabilityOwners = CapabilityOwners



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/lockup/query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from google_apis.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from osmosis.lockup import lock_pb2 as osmosis_dot_lockup_dot_lock__pb2
from osmosis.lockup import params_pb2 as osmosis_dot_lockup_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aosmosis/lockup/query.proto\x12\x0eosmosis.lockup\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x19osmosis/lockup/lock.proto\x1a\x1bosmosis/lockup/params.proto\"\x16\n\x14ModuleBalanceRequest\"s\n\x15ModuleBalanceResponse\x12Z\n\x05\x63oins\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"\x1b\n\x19ModuleLockedAmountRequest\"x\n\x1aModuleLockedAmountResponse\x12Z\n\x05\x63oins\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"@\n\x1d\x41\x63\x63ountUnlockableCoinsRequest\x12\x1f\n\x05owner\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"owner\"\"|\n\x1e\x41\x63\x63ountUnlockableCoinsResponse\x12Z\n\x05\x63oins\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"?\n\x1c\x41\x63\x63ountUnlockingCoinsRequest\x12\x1f\n\x05owner\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"owner\"\"{\n\x1d\x41\x63\x63ountUnlockingCoinsResponse\x12Z\n\x05\x63oins\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"<\n\x19\x41\x63\x63ountLockedCoinsRequest\x12\x1f\n\x05owner\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"owner\"\"x\n\x1a\x41\x63\x63ountLockedCoinsResponse\x12Z\n\x05\x63oins\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"\x8c\x01\n\x1c\x41\x63\x63ountLockedPastTimeRequest\x12\x1f\n\x05owner\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"owner\"\x12K\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x1c\x90\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x10yaml:\"timestamp\"\"P\n\x1d\x41\x63\x63ountLockedPastTimeResponse\x12/\n\x05locks\x18\x01 \x03(\x0b\x32\x1a.osmosis.lockup.PeriodLockB\x04\xc8\xde\x1f\x00\"\x9c\x01\n,AccountLockedPastTimeNotUnlockingOnlyRequest\x12\x1f\n\x05owner\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"owner\"\x12K\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x1c\x90\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x10yaml:\"timestamp\"\"`\n-AccountLockedPastTimeNotUnlockingOnlyResponse\x12/\n\x05locks\x18\x01 \x03(\x0b\x32\x1a.osmosis.lockup.PeriodLockB\x04\xc8\xde\x1f\x00\"\x90\x01\n AccountUnlockedBeforeTimeRequest\x12\x1f\n\x05owner\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"owner\"\x12K\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x1c\x90\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x10yaml:\"timestamp\"\"T\n!AccountUnlockedBeforeTimeResponse\x12/\n\x05locks\x18\x01 \x03(\x0b\x32\x1a.osmosis.lockup.PeriodLockB\x04\xc8\xde\x1f\x00\"\xa0\x01\n!AccountLockedPastTimeDenomRequest\x12\x1f\n\x05owner\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"owner\"\x12K\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x1c\x90\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x10yaml:\"timestamp\"\x12\r\n\x05\x64\x65nom\x18\x03 \x01(\t\"U\n\"AccountLockedPastTimeDenomResponse\x12/\n\x05locks\x18\x01 \x03(\x0b\x32\x1a.osmosis.lockup.PeriodLockB\x04\xc8\xde\x1f\x00\"m\n\x12LockedDenomRequest\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12H\n\x08\x64uration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x1b\x98\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x0fyaml:\"duration\"\"f\n\x13LockedDenomResponse\x12O\n\x06\x61mount\x18\x01 \x01(\tB?\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\ryaml:\"amount\"\xc8\xde\x1f\x00\" \n\rLockedRequest\x12\x0f\n\x07lock_id\x18\x01 \x01(\x04\":\n\x0eLockedResponse\x12(\n\x04lock\x18\x01 \x01(\x0b\x32\x1a.osmosis.lockup.PeriodLock\"4\n!SyntheticLockupsByLockupIDRequest\x12\x0f\n\x07lock_id\x18\x01 \x01(\x04\"b\n\"SyntheticLockupsByLockupIDResponse\x12<\n\x0fsynthetic_locks\x18\x01 \x03(\x0b\x32\x1d.osmosis.lockup.SyntheticLockB\x04\xc8\xde\x1f\x00\"\x8f\x01\n\"AccountLockedLongerDurationRequest\x12\x1f\n\x05owner\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"owner\"\x12H\n\x08\x64uration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x1b\x98\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x0fyaml:\"duration\"\"V\n#AccountLockedLongerDurationResponse\x12/\n\x05locks\x18\x01 \x03(\x0b\x32\x1a.osmosis.lockup.PeriodLockB\x04\xc8\xde\x1f\x00\"\x89\x01\n\x1c\x41\x63\x63ountLockedDurationRequest\x12\x1f\n\x05owner\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"owner\"\x12H\n\x08\x64uration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x1b\x98\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x0fyaml:\"duration\"\"P\n\x1d\x41\x63\x63ountLockedDurationResponse\x12/\n\x05locks\x18\x01 \x03(\x0b\x32\x1a.osmosis.lockup.PeriodLockB\x04\xc8\xde\x1f\x00\"\x9f\x01\n2AccountLockedLongerDurationNotUnlockingOnlyRequest\x12\x1f\n\x05owner\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"owner\"\x12H\n\x08\x64uration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x1b\x98\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x0fyaml:\"duration\"\"f\n3AccountLockedLongerDurationNotUnlockingOnlyResponse\x12/\n\x05locks\x18\x01 \x03(\x0b\x32\x1a.osmosis.lockup.PeriodLockB\x04\xc8\xde\x1f\x00\"\xa3\x01\n\'AccountLockedLongerDurationDenomRequest\x12\x1f\n\x05owner\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"owner\"\x12H\n\x08\x64uration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x1b\x98\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x0fyaml:\"duration\"\x12\r\n\x05\x64\x65nom\x18\x03 \x01(\t\"[\n(AccountLockedLongerDurationDenomResponse\x12/\n\x05locks\x18\x01 \x03(\x0b\x32\x1a.osmosis.lockup.PeriodLockB\x04\xc8\xde\x1f\x00\"\x14\n\x12QueryParamsRequest\"C\n\x13QueryParamsResponse\x12,\n\x06params\x18\x01 \x01(\x0b\x32\x16.osmosis.lockup.ParamsB\x04\xc8\xde\x1f\x00\x32\xfc\x18\n\x05Query\x12\x8c\x01\n\rModuleBalance\x12$.osmosis.lockup.ModuleBalanceRequest\x1a%.osmosis.lockup.ModuleBalanceResponse\".\x82\xd3\xe4\x93\x02(\x12&/osmosis/lockup/v1beta1/module_balance\x12\xa1\x01\n\x12ModuleLockedAmount\x12).osmosis.lockup.ModuleLockedAmountRequest\x1a*.osmosis.lockup.ModuleLockedAmountResponse\"4\x82\xd3\xe4\x93\x02.\x12,/osmosis/lockup/v1beta1/module_locked_amount\x12\xb9\x01\n\x16\x41\x63\x63ountUnlockableCoins\x12-.osmosis.lockup.AccountUnlockableCoinsRequest\x1a..osmosis.lockup.AccountUnlockableCoinsResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/osmosis/lockup/v1beta1/account_unlockable_coins/{owner}\x12\xb5\x01\n\x15\x41\x63\x63ountUnlockingCoins\x12,.osmosis.lockup.AccountUnlockingCoinsRequest\x1a-.osmosis.lockup.AccountUnlockingCoinsResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/osmosis/lockup/v1beta1/account_unlocking_coins/{owner}\x12\xa9\x01\n\x12\x41\x63\x63ountLockedCoins\x12).osmosis.lockup.AccountLockedCoinsRequest\x1a*.osmosis.lockup.AccountLockedCoinsResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/osmosis/lockup/v1beta1/account_locked_coins/{owner}\x12\xb5\x01\n\x15\x41\x63\x63ountLockedPastTime\x12,.osmosis.lockup.AccountLockedPastTimeRequest\x1a-.osmosis.lockup.AccountLockedPastTimeResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/osmosis/lockup/v1beta1/account_locked_pasttime/{owner}\x12\xf8\x01\n%AccountLockedPastTimeNotUnlockingOnly\x12<.osmosis.lockup.AccountLockedPastTimeNotUnlockingOnlyRequest\x1a=.osmosis.lockup.AccountLockedPastTimeNotUnlockingOnlyResponse\"R\x82\xd3\xe4\x93\x02L\x12J/osmosis/lockup/v1beta1/account_locked_pasttime_not_unlocking_only/{owner}\x12\xc6\x01\n\x19\x41\x63\x63ountUnlockedBeforeTime\x12\x30.osmosis.lockup.AccountUnlockedBeforeTimeRequest\x1a\x31.osmosis.lockup.AccountUnlockedBeforeTimeResponse\"D\x82\xd3\xe4\x93\x02>\x12</osmosis/lockup/v1beta1/account_unlocked_before_time/{owner}\x12\xca\x01\n\x1a\x41\x63\x63ountLockedPastTimeDenom\x12\x31.osmosis.lockup.AccountLockedPastTimeDenomRequest\x1a\x32.osmosis.lockup.AccountLockedPastTimeDenomResponse\"E\x82\xd3\xe4\x93\x02?\x12=/osmosis/lockup/v1beta1/account_locked_pasttime_denom/{owner}\x12\x84\x01\n\x0bLockedDenom\x12\".osmosis.lockup.LockedDenomRequest\x1a#.osmosis.lockup.LockedDenomResponse\",\x82\xd3\xe4\x93\x02&\x12$/osmosis/lockup/v1beta1/locked_denom\x12\x83\x01\n\nLockedByID\x12\x1d.osmosis.lockup.LockedRequest\x1a\x1e.osmosis.lockup.LockedResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./osmosis/lockup/v1beta1/locked_by_id/{lock_id}\x12\xcb\x01\n\x1aSyntheticLockupsByLockupID\x12\x31.osmosis.lockup.SyntheticLockupsByLockupIDRequest\x1a\x32.osmosis.lockup.SyntheticLockupsByLockupIDResponse\"F\x82\xd3\xe4\x93\x02@\x12>/osmosis/lockup/v1beta1/synthetic_lockups_by_lock_id/{lock_id}\x12\xce\x01\n\x1b\x41\x63\x63ountLockedLongerDuration\x12\x32.osmosis.lockup.AccountLockedLongerDurationRequest\x1a\x33.osmosis.lockup.AccountLockedLongerDurationResponse\"F\x82\xd3\xe4\x93\x02@\x12>/osmosis/lockup/v1beta1/account_locked_longer_duration/{owner}\x12\xb5\x01\n\x15\x41\x63\x63ountLockedDuration\x12,.osmosis.lockup.AccountLockedDurationRequest\x1a-.osmosis.lockup.AccountLockedDurationResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/osmosis/lockup/v1beta1/account_locked_duration/{owner}\x12\x91\x02\n+AccountLockedLongerDurationNotUnlockingOnly\x12\x42.osmosis.lockup.AccountLockedLongerDurationNotUnlockingOnlyRequest\x1a\x43.osmosis.lockup.AccountLockedLongerDurationNotUnlockingOnlyResponse\"Y\x82\xd3\xe4\x93\x02S\x12Q/osmosis/lockup/v1beta1/account_locked_longer_duration_not_unlocking_only/{owner}\x12\xe3\x01\n AccountLockedLongerDurationDenom\x12\x37.osmosis.lockup.AccountLockedLongerDurationDenomRequest\x1a\x38.osmosis.lockup.AccountLockedLongerDurationDenomResponse\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/osmosis/lockup/v1beta1/account_locked_longer_duration_denom/{owner}\x12y\n\x06Params\x12\".osmosis.lockup.QueryParamsRequest\x1a#.osmosis.lockup.QueryParamsResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/osmosis/lockup/v1beta1/paramsB4Z2github.com/osmosis-labs/osmosis/v14/x/lockup/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.lockup.query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z2github.com/osmosis-labs/osmosis/v14/x/lockup/types'
  _MODULEBALANCERESPONSE.fields_by_name['coins']._options = None
  _MODULEBALANCERESPONSE.fields_by_name['coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MODULELOCKEDAMOUNTRESPONSE.fields_by_name['coins']._options = None
  _MODULELOCKEDAMOUNTRESPONSE.fields_by_name['coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _ACCOUNTUNLOCKABLECOINSREQUEST.fields_by_name['owner']._options = None
  _ACCOUNTUNLOCKABLECOINSREQUEST.fields_by_name['owner']._serialized_options = b'\362\336\037\014yaml:\"owner\"'
  _ACCOUNTUNLOCKABLECOINSRESPONSE.fields_by_name['coins']._options = None
  _ACCOUNTUNLOCKABLECOINSRESPONSE.fields_by_name['coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _ACCOUNTUNLOCKINGCOINSREQUEST.fields_by_name['owner']._options = None
  _ACCOUNTUNLOCKINGCOINSREQUEST.fields_by_name['owner']._serialized_options = b'\362\336\037\014yaml:\"owner\"'
  _ACCOUNTUNLOCKINGCOINSRESPONSE.fields_by_name['coins']._options = None
  _ACCOUNTUNLOCKINGCOINSRESPONSE.fields_by_name['coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _ACCOUNTLOCKEDCOINSREQUEST.fields_by_name['owner']._options = None
  _ACCOUNTLOCKEDCOINSREQUEST.fields_by_name['owner']._serialized_options = b'\362\336\037\014yaml:\"owner\"'
  _ACCOUNTLOCKEDCOINSRESPONSE.fields_by_name['coins']._options = None
  _ACCOUNTLOCKEDCOINSRESPONSE.fields_by_name['coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _ACCOUNTLOCKEDPASTTIMEREQUEST.fields_by_name['owner']._options = None
  _ACCOUNTLOCKEDPASTTIMEREQUEST.fields_by_name['owner']._serialized_options = b'\362\336\037\014yaml:\"owner\"'
  _ACCOUNTLOCKEDPASTTIMEREQUEST.fields_by_name['timestamp']._options = None
  _ACCOUNTLOCKEDPASTTIMEREQUEST.fields_by_name['timestamp']._serialized_options = b'\220\337\037\001\310\336\037\000\362\336\037\020yaml:\"timestamp\"'
  _ACCOUNTLOCKEDPASTTIMERESPONSE.fields_by_name['locks']._options = None
  _ACCOUNTLOCKEDPASTTIMERESPONSE.fields_by_name['locks']._serialized_options = b'\310\336\037\000'
  _ACCOUNTLOCKEDPASTTIMENOTUNLOCKINGONLYREQUEST.fields_by_name['owner']._options = None
  _ACCOUNTLOCKEDPASTTIMENOTUNLOCKINGONLYREQUEST.fields_by_name['owner']._serialized_options = b'\362\336\037\014yaml:\"owner\"'
  _ACCOUNTLOCKEDPASTTIMENOTUNLOCKINGONLYREQUEST.fields_by_name['timestamp']._options = None
  _ACCOUNTLOCKEDPASTTIMENOTUNLOCKINGONLYREQUEST.fields_by_name['timestamp']._serialized_options = b'\220\337\037\001\310\336\037\000\362\336\037\020yaml:\"timestamp\"'
  _ACCOUNTLOCKEDPASTTIMENOTUNLOCKINGONLYRESPONSE.fields_by_name['locks']._options = None
  _ACCOUNTLOCKEDPASTTIMENOTUNLOCKINGONLYRESPONSE.fields_by_name['locks']._serialized_options = b'\310\336\037\000'
  _ACCOUNTUNLOCKEDBEFORETIMEREQUEST.fields_by_name['owner']._options = None
  _ACCOUNTUNLOCKEDBEFORETIMEREQUEST.fields_by_name['owner']._serialized_options = b'\362\336\037\014yaml:\"owner\"'
  _ACCOUNTUNLOCKEDBEFORETIMEREQUEST.fields_by_name['timestamp']._options = None
  _ACCOUNTUNLOCKEDBEFORETIMEREQUEST.fields_by_name['timestamp']._serialized_options = b'\220\337\037\001\310\336\037\000\362\336\037\020yaml:\"timestamp\"'
  _ACCOUNTUNLOCKEDBEFORETIMERESPONSE.fields_by_name['locks']._options = None
  _ACCOUNTUNLOCKEDBEFORETIMERESPONSE.fields_by_name['locks']._serialized_options = b'\310\336\037\000'
  _ACCOUNTLOCKEDPASTTIMEDENOMREQUEST.fields_by_name['owner']._options = None
  _ACCOUNTLOCKEDPASTTIMEDENOMREQUEST.fields_by_name['owner']._serialized_options = b'\362\336\037\014yaml:\"owner\"'
  _ACCOUNTLOCKEDPASTTIMEDENOMREQUEST.fields_by_name['timestamp']._options = None
  _ACCOUNTLOCKEDPASTTIMEDENOMREQUEST.fields_by_name['timestamp']._serialized_options = b'\220\337\037\001\310\336\037\000\362\336\037\020yaml:\"timestamp\"'
  _ACCOUNTLOCKEDPASTTIMEDENOMRESPONSE.fields_by_name['locks']._options = None
  _ACCOUNTLOCKEDPASTTIMEDENOMRESPONSE.fields_by_name['locks']._serialized_options = b'\310\336\037\000'
  _LOCKEDDENOMREQUEST.fields_by_name['duration']._options = None
  _LOCKEDDENOMREQUEST.fields_by_name['duration']._serialized_options = b'\230\337\037\001\310\336\037\000\362\336\037\017yaml:\"duration\"'
  _LOCKEDDENOMRESPONSE.fields_by_name['amount']._options = None
  _LOCKEDDENOMRESPONSE.fields_by_name['amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\ryaml:\"amount\"\310\336\037\000'
  _SYNTHETICLOCKUPSBYLOCKUPIDRESPONSE.fields_by_name['synthetic_locks']._options = None
  _SYNTHETICLOCKUPSBYLOCKUPIDRESPONSE.fields_by_name['synthetic_locks']._serialized_options = b'\310\336\037\000'
  _ACCOUNTLOCKEDLONGERDURATIONREQUEST.fields_by_name['owner']._options = None
  _ACCOUNTLOCKEDLONGERDURATIONREQUEST.fields_by_name['owner']._serialized_options = b'\362\336\037\014yaml:\"owner\"'
  _ACCOUNTLOCKEDLONGERDURATIONREQUEST.fields_by_name['duration']._options = None
  _ACCOUNTLOCKEDLONGERDURATIONREQUEST.fields_by_name['duration']._serialized_options = b'\230\337\037\001\310\336\037\000\362\336\037\017yaml:\"duration\"'
  _ACCOUNTLOCKEDLONGERDURATIONRESPONSE.fields_by_name['locks']._options = None
  _ACCOUNTLOCKEDLONGERDURATIONRESPONSE.fields_by_name['locks']._serialized_options = b'\310\336\037\000'
  _ACCOUNTLOCKEDDURATIONREQUEST.fields_by_name['owner']._options = None
  _ACCOUNTLOCKEDDURATIONREQUEST.fields_by_name['owner']._serialized_options = b'\362\336\037\014yaml:\"owner\"'
  _ACCOUNTLOCKEDDURATIONREQUEST.fields_by_name['duration']._options = None
  _ACCOUNTLOCKEDDURATIONREQUEST.fields_by_name['duration']._serialized_options = b'\230\337\037\001\310\336\037\000\362\336\037\017yaml:\"duration\"'
  _ACCOUNTLOCKEDDURATIONRESPONSE.fields_by_name['locks']._options = None
  _ACCOUNTLOCKEDDURATIONRESPONSE.fields_by_name['locks']._serialized_options = b'\310\336\037\000'
  _ACCOUNTLOCKEDLONGERDURATIONNOTUNLOCKINGONLYREQUEST.fields_by_name['owner']._options = None
  _ACCOUNTLOCKEDLONGERDURATIONNOTUNLOCKINGONLYREQUEST.fields_by_name['owner']._serialized_options = b'\362\336\037\014yaml:\"owner\"'
  _ACCOUNTLOCKEDLONGERDURATIONNOTUNLOCKINGONLYREQUEST.fields_by_name['duration']._options = None
  _ACCOUNTLOCKEDLONGERDURATIONNOTUNLOCKINGONLYREQUEST.fields_by_name['duration']._serialized_options = b'\230\337\037\001\310\336\037\000\362\336\037\017yaml:\"duration\"'
  _ACCOUNTLOCKEDLONGERDURATIONNOTUNLOCKINGONLYRESPONSE.fields_by_name['locks']._options = None
  _ACCOUNTLOCKEDLONGERDURATIONNOTUNLOCKINGONLYRESPONSE.fields_by_name['locks']._serialized_options = b'\310\336\037\000'
  _ACCOUNTLOCKEDLONGERDURATIONDENOMREQUEST.fields_by_name['owner']._options = None
  _ACCOUNTLOCKEDLONGERDURATIONDENOMREQUEST.fields_by_name['owner']._serialized_options = b'\362\336\037\014yaml:\"owner\"'
  _ACCOUNTLOCKEDLONGERDURATIONDENOMREQUEST.fields_by_name['duration']._options = None
  _ACCOUNTLOCKEDLONGERDURATIONDENOMREQUEST.fields_by_name['duration']._serialized_options = b'\230\337\037\001\310\336\037\000\362\336\037\017yaml:\"duration\"'
  _ACCOUNTLOCKEDLONGERDURATIONDENOMRESPONSE.fields_by_name['locks']._options = None
  _ACCOUNTLOCKEDLONGERDURATIONDENOMRESPONSE.fields_by_name['locks']._serialized_options = b'\310\336\037\000'
  _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERY.methods_by_name['ModuleBalance']._options = None
  _QUERY.methods_by_name['ModuleBalance']._serialized_options = b'\202\323\344\223\002(\022&/osmosis/lockup/v1beta1/module_balance'
  _QUERY.methods_by_name['ModuleLockedAmount']._options = None
  _QUERY.methods_by_name['ModuleLockedAmount']._serialized_options = b'\202\323\344\223\002.\022,/osmosis/lockup/v1beta1/module_locked_amount'
  _QUERY.methods_by_name['AccountUnlockableCoins']._options = None
  _QUERY.methods_by_name['AccountUnlockableCoins']._serialized_options = b'\202\323\344\223\002:\0228/osmosis/lockup/v1beta1/account_unlockable_coins/{owner}'
  _QUERY.methods_by_name['AccountUnlockingCoins']._options = None
  _QUERY.methods_by_name['AccountUnlockingCoins']._serialized_options = b'\202\323\344\223\0029\0227/osmosis/lockup/v1beta1/account_unlocking_coins/{owner}'
  _QUERY.methods_by_name['AccountLockedCoins']._options = None
  _QUERY.methods_by_name['AccountLockedCoins']._serialized_options = b'\202\323\344\223\0026\0224/osmosis/lockup/v1beta1/account_locked_coins/{owner}'
  _QUERY.methods_by_name['AccountLockedPastTime']._options = None
  _QUERY.methods_by_name['AccountLockedPastTime']._serialized_options = b'\202\323\344\223\0029\0227/osmosis/lockup/v1beta1/account_locked_pasttime/{owner}'
  _QUERY.methods_by_name['AccountLockedPastTimeNotUnlockingOnly']._options = None
  _QUERY.methods_by_name['AccountLockedPastTimeNotUnlockingOnly']._serialized_options = b'\202\323\344\223\002L\022J/osmosis/lockup/v1beta1/account_locked_pasttime_not_unlocking_only/{owner}'
  _QUERY.methods_by_name['AccountUnlockedBeforeTime']._options = None
  _QUERY.methods_by_name['AccountUnlockedBeforeTime']._serialized_options = b'\202\323\344\223\002>\022</osmosis/lockup/v1beta1/account_unlocked_before_time/{owner}'
  _QUERY.methods_by_name['AccountLockedPastTimeDenom']._options = None
  _QUERY.methods_by_name['AccountLockedPastTimeDenom']._serialized_options = b'\202\323\344\223\002?\022=/osmosis/lockup/v1beta1/account_locked_pasttime_denom/{owner}'
  _QUERY.methods_by_name['LockedDenom']._options = None
  _QUERY.methods_by_name['LockedDenom']._serialized_options = b'\202\323\344\223\002&\022$/osmosis/lockup/v1beta1/locked_denom'
  _QUERY.methods_by_name['LockedByID']._options = None
  _QUERY.methods_by_name['LockedByID']._serialized_options = b'\202\323\344\223\0020\022./osmosis/lockup/v1beta1/locked_by_id/{lock_id}'
  _QUERY.methods_by_name['SyntheticLockupsByLockupID']._options = None
  _QUERY.methods_by_name['SyntheticLockupsByLockupID']._serialized_options = b'\202\323\344\223\002@\022>/osmosis/lockup/v1beta1/synthetic_lockups_by_lock_id/{lock_id}'
  _QUERY.methods_by_name['AccountLockedLongerDuration']._options = None
  _QUERY.methods_by_name['AccountLockedLongerDuration']._serialized_options = b'\202\323\344\223\002@\022>/osmosis/lockup/v1beta1/account_locked_longer_duration/{owner}'
  _QUERY.methods_by_name['AccountLockedDuration']._options = None
  _QUERY.methods_by_name['AccountLockedDuration']._serialized_options = b'\202\323\344\223\0029\0227/osmosis/lockup/v1beta1/account_locked_duration/{owner}'
  _QUERY.methods_by_name['AccountLockedLongerDurationNotUnlockingOnly']._options = None
  _QUERY.methods_by_name['AccountLockedLongerDurationNotUnlockingOnly']._serialized_options = b'\202\323\344\223\002S\022Q/osmosis/lockup/v1beta1/account_locked_longer_duration_not_unlocking_only/{owner}'
  _QUERY.methods_by_name['AccountLockedLongerDurationDenom']._options = None
  _QUERY.methods_by_name['AccountLockedLongerDurationDenom']._serialized_options = b'\202\323\344\223\002F\022D/osmosis/lockup/v1beta1/account_locked_longer_duration_denom/{owner}'
  _QUERY.methods_by_name['Params']._options = None
  _QUERY.methods_by_name['Params']._serialized_options = b'\202\323\344\223\002 \022\036/osmosis/lockup/v1beta1/params'
  _MODULEBALANCEREQUEST._serialized_start=251
  _MODULEBALANCEREQUEST._serialized_end=273
  _MODULEBALANCERESPONSE._serialized_start=275
  _MODULEBALANCERESPONSE._serialized_end=390
  _MODULELOCKEDAMOUNTREQUEST._serialized_start=392
  _MODULELOCKEDAMOUNTREQUEST._serialized_end=419
  _MODULELOCKEDAMOUNTRESPONSE._serialized_start=421
  _MODULELOCKEDAMOUNTRESPONSE._serialized_end=541
  _ACCOUNTUNLOCKABLECOINSREQUEST._serialized_start=543
  _ACCOUNTUNLOCKABLECOINSREQUEST._serialized_end=607
  _ACCOUNTUNLOCKABLECOINSRESPONSE._serialized_start=609
  _ACCOUNTUNLOCKABLECOINSRESPONSE._serialized_end=733
  _ACCOUNTUNLOCKINGCOINSREQUEST._serialized_start=735
  _ACCOUNTUNLOCKINGCOINSREQUEST._serialized_end=798
  _ACCOUNTUNLOCKINGCOINSRESPONSE._serialized_start=800
  _ACCOUNTUNLOCKINGCOINSRESPONSE._serialized_end=923
  _ACCOUNTLOCKEDCOINSREQUEST._serialized_start=925
  _ACCOUNTLOCKEDCOINSREQUEST._serialized_end=985
  _ACCOUNTLOCKEDCOINSRESPONSE._serialized_start=987
  _ACCOUNTLOCKEDCOINSRESPONSE._serialized_end=1107
  _ACCOUNTLOCKEDPASTTIMEREQUEST._serialized_start=1110
  _ACCOUNTLOCKEDPASTTIMEREQUEST._serialized_end=1250
  _ACCOUNTLOCKEDPASTTIMERESPONSE._serialized_start=1252
  _ACCOUNTLOCKEDPASTTIMERESPONSE._serialized_end=1332
  _ACCOUNTLOCKEDPASTTIMENOTUNLOCKINGONLYREQUEST._serialized_start=1335
  _ACCOUNTLOCKEDPASTTIMENOTUNLOCKINGONLYREQUEST._serialized_end=1491
  _ACCOUNTLOCKEDPASTTIMENOTUNLOCKINGONLYRESPONSE._serialized_start=1493
  _ACCOUNTLOCKEDPASTTIMENOTUNLOCKINGONLYRESPONSE._serialized_end=1589
  _ACCOUNTUNLOCKEDBEFORETIMEREQUEST._serialized_start=1592
  _ACCOUNTUNLOCKEDBEFORETIMEREQUEST._serialized_end=1736
  _ACCOUNTUNLOCKEDBEFORETIMERESPONSE._serialized_start=1738
  _ACCOUNTUNLOCKEDBEFORETIMERESPONSE._serialized_end=1822
  _ACCOUNTLOCKEDPASTTIMEDENOMREQUEST._serialized_start=1825
  _ACCOUNTLOCKEDPASTTIMEDENOMREQUEST._serialized_end=1985
  _ACCOUNTLOCKEDPASTTIMEDENOMRESPONSE._serialized_start=1987
  _ACCOUNTLOCKEDPASTTIMEDENOMRESPONSE._serialized_end=2072
  _LOCKEDDENOMREQUEST._serialized_start=2074
  _LOCKEDDENOMREQUEST._serialized_end=2183
  _LOCKEDDENOMRESPONSE._serialized_start=2185
  _LOCKEDDENOMRESPONSE._serialized_end=2287
  _LOCKEDREQUEST._serialized_start=2289
  _LOCKEDREQUEST._serialized_end=2321
  _LOCKEDRESPONSE._serialized_start=2323
  _LOCKEDRESPONSE._serialized_end=2381
  _SYNTHETICLOCKUPSBYLOCKUPIDREQUEST._serialized_start=2383
  _SYNTHETICLOCKUPSBYLOCKUPIDREQUEST._serialized_end=2435
  _SYNTHETICLOCKUPSBYLOCKUPIDRESPONSE._serialized_start=2437
  _SYNTHETICLOCKUPSBYLOCKUPIDRESPONSE._serialized_end=2535
  _ACCOUNTLOCKEDLONGERDURATIONREQUEST._serialized_start=2538
  _ACCOUNTLOCKEDLONGERDURATIONREQUEST._serialized_end=2681
  _ACCOUNTLOCKEDLONGERDURATIONRESPONSE._serialized_start=2683
  _ACCOUNTLOCKEDLONGERDURATIONRESPONSE._serialized_end=2769
  _ACCOUNTLOCKEDDURATIONREQUEST._serialized_start=2772
  _ACCOUNTLOCKEDDURATIONREQUEST._serialized_end=2909
  _ACCOUNTLOCKEDDURATIONRESPONSE._serialized_start=2911
  _ACCOUNTLOCKEDDURATIONRESPONSE._serialized_end=2991
  _ACCOUNTLOCKEDLONGERDURATIONNOTUNLOCKINGONLYREQUEST._serialized_start=2994
  _ACCOUNTLOCKEDLONGERDURATIONNOTUNLOCKINGONLYREQUEST._serialized_end=3153
  _ACCOUNTLOCKEDLONGERDURATIONNOTUNLOCKINGONLYRESPONSE._serialized_start=3155
  _ACCOUNTLOCKEDLONGERDURATIONNOTUNLOCKINGONLYRESPONSE._serialized_end=3257
  _ACCOUNTLOCKEDLONGERDURATIONDENOMREQUEST._serialized_start=3260
  _ACCOUNTLOCKEDLONGERDURATIONDENOMREQUEST._serialized_end=3423
  _ACCOUNTLOCKEDLONGERDURATIONDENOMRESPONSE._serialized_start=3425
  _ACCOUNTLOCKEDLONGERDURATIONDENOMRESPONSE._serialized_end=3516
  _QUERYPARAMSREQUEST._serialized_start=3518
  _QUERYPARAMSREQUEST._serialized_end=3538
  _QUERYPARAMSRESPONSE._serialized_start=3540
  _QUERYPARAMSRESPONSE._serialized_end=3607
  _QUERY._serialized_start=3610
  _QUERY._serialized_end=6806
# @@protoc_insertion_point(module_scope)
